@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2022 -- leonerd@leonerd.org.uk
 
-package Object::Pad::MetaFunctions 0.67;
+package Object::Pad::MetaFunctions 0.68;
 
 use v5.14;
 use warnings;
@@ -134,9 +134,9 @@ only read access is required, use L</get_field> instead.
 
 =head2 get_field
 
-   $scalar = ref_field( $fieldname, $obj )
-   @array  = ref_field( $fieldname, $obj )
-   %hash   = ref_field( $fieldname, $obj )
+   $scalar = get_field( $fieldname, $obj )
+   @array  = get_field( $fieldname, $obj )
+   %hash   = get_field( $fieldname, $obj )
 
 I<Since version 0.67.>
 
